@@ -47,6 +47,16 @@ def get_pr_build_number(repo, commit_sha):
         return None
 
 
+def get_user():
+    try:
+        user = requests.get(
+            f"{baseurl}/api/user", headers={"Authorization": f"Bearer {tokens.drone}"},
+        ).json()
+        return user
+    except Exception:
+        return None
+
+
 def get_build_url(repo, build_number):
     if build_number:
         return f"{baseurl}/primait/{repo}/{build_number}"
